@@ -9,15 +9,15 @@ import (
 //go:embed scripts/omp.nu
 var nuInit string
 
-func (f Feature) Nu() Code {
+func (f Features) Nu() Code {
 	switch f {
 	case Transient:
 		return `$env.TRANSIENT_PROMPT_COMMAND = {|| _omp_get_prompt transient }`
 	case Upgrade:
-		return "^$_omp_executable upgrade"
+		return "^$_omp_executable upgrade --auto"
 	case Notice:
 		return "^$_omp_executable notice"
-	case PromptMark, RPrompt, PoshGit, Azure, LineError, Jobs, Tooltips, FTCSMarks, CursorPositioning, Async:
+	case PromptMark, RPrompt, PoshGit, Azure, LineError, Jobs, Tooltips, FTCSMarks, CursorPositioning, Async, Streaming, KeyHandlers:
 		fallthrough
 	default:
 		return ""
@@ -25,7 +25,7 @@ func (f Feature) Nu() Code {
 }
 
 func quoteNuStr(str string) string {
-	if len(str) == 0 {
+	if str == "" {
 		return "''"
 	}
 
